@@ -276,30 +276,55 @@ parallel.resamples <- function (x, data = NULL, models = x$models, metric = x$me
     
 }
 
-splom.resamples <- function (x, data = NULL, models = x$models, metric = x$metric[1], panelRange = NULL, ...) 
+splom.resamples <- function (x, data = NULL, variables = "models",
+                             models = x$models,
+                             metric = NULL,
+                             panelRange = NULL,
+                             ...) 
 {
-  if(length(metric) != 1) stop("exactly one metric must be given")
 
-  tmpData <- x$values[, grep(paste("~", metric, sep = ""),
-                             names(x$value),
-                             fixed = TRUE),
-                      drop = FALSE]
-  names(tmpData) <- gsub(paste("~", metric, sep = ""),
-                         "",
-                         names(tmpData),
-                         fixed = TRUE)
-  if(is.null(panelRange)) panelRange <- extendrange(tmpData)
-  splom(~tmpData,
-        panel = function(x, y)
+  if(variables == "models")
+    {
+
+      if(is.null(metric)) metric <- x$metric[1]
+      if(length(metric) != 1) stop("exactly one metric must be given")
+
+      tmpData <- x$values[, grep(paste("~", metric, sep = ""),
+                                 names(x$value),
+                                 fixed = TRUE),
+                          drop = FALSE]
+      names(tmpData) <- gsub(paste("~", metric, sep = ""),
+                             "",
+                             names(tmpData),
+                             fixed = TRUE)
+      if(is.null(panelRange)) panelRange <- extendrange(tmpData)
+      splom(~tmpData,
+            panel = function(x, y)
+            {
+              panel.splom(x, y, ...)
+              panel.abline(0, 1, lty = 2, col = "darkgrey")
+
+            },
+            main = caret:::useMathSymbols(metric),
+            prepanel.limits = function(x) panelRange,
+            ...)
+    } else{
+      if(variables == "metrics")
         {
-          panel.splom(x, y, ...)
-          panel.abline(0, 1, lty = 2, col = "darkgrey")
+      if(is.null(metric)) metric <- x$metric
+          if(length(metric) < 2) stop("There should be at least two metrics")
+          plotData <- melt(x$values, id.vars = "Resample")
+          tmp <- strsplit(as.character(plotData$variable), "~", fixed = TRUE)
+          plotData$Model <- unlist(lapply(tmp, function(x) x[1]))
+          plotData$Metric <- unlist(lapply(tmp, function(x) x[2]))
+          plotData <- subset(plotData, Model %in% models & Metric  %in% metric)
+          means <- cast(plotData, Model ~ Metric, mean)
+          splom(~means[, metric], groups = means$Model, ...)
 
-          },
-        main = useMathSymbols(metric),
-        prepanel.limits = function(x) panelRange,
-        ...)
-                         
+        } else stop ("'variables' should be either 'models' or 'metrics'")
+
+    }
+  
 }
 
 
@@ -332,6 +357,57 @@ bwplot.resamples <- function (x, data = NULL, models = x$models, metric = x$metr
 }
 
 
+
+dotplot.resamples <- function (x, data = NULL, models = x$models, metric = x$metric, conf.level = 0.95, ...) 
+{
+  plotData <- melt(x$values, id.vars = "Resample")
+  tmp <- strsplit(as.character(plotData$variable), "~", fixed = TRUE)
+  plotData$Model <- unlist(lapply(tmp, function(x) x[1]))
+  plotData$Metric <- unlist(lapply(tmp, function(x) x[2]))
+  plotData <- subset(plotData, Model %in% models & Metric  %in% metric)
+  plotData$variable <- factor(as.character(plotData$variable))
+
+  plotData <- split(plotData, plotData$variable)
+  results <- lapply(plotData,
+                    function(x, cl)
+                    {
+                      ttest <- t.test(x$value, conf.level = cl)
+                      out <- c(ttest$conf.int, ttest$estimate)
+                      names(out) <- c("LowerLimit", "UpperLimit", "Estimate")
+                      out
+                    },
+                    cl = conf.level)
+  results <- do.call("rbind", results)
+  results <- melt(results)
+  tmp <- strsplit(as.character(results$X1), "~", fixed = TRUE)
+  results$Model <- unlist(lapply(tmp, function(x) x[1]))
+  results$Metric <- unlist(lapply(tmp, function(x) x[2]))
+  dotplot(Model ~ value|Metric,
+         data = results,
+         xlab = "",
+         panel = function(x, y)
+         {
+           plotTheme <- trellis.par.get()
+           y <- as.numeric(y)
+           
+           vals <- aggregate(x, list(group = y), function(x) c(min = min(x), mid = median(x), max = max(x)))
+         
+           panel.dotplot(vals$x[,"mid"], vals$group,
+                        pch = plotTheme$plot.symbol$pch,
+                        col = plotTheme$plot.symbol$col)
+           panel.segments(vals$x[,"min"], vals$group, 
+                          vals$x[,"max"], vals$group, 
+                          lty = plotTheme$plot.line$lty,
+                        col = plotTheme$plot.line$col,
+                          lwd = plotTheme$plot.line$lwd)
+          
+         },
+          sub = paste("Confidence Level:", conf.level),
+         ...)
+  
+}
+
+
 diff.resamples <- function(x,
                            models = x$models,
                            metric = x$metrics,
@@ -627,6 +703,7 @@ if(FALSE)
     tmp <- createDataPartition(logBBB,
                                p = .8,
                                times = 5)
+    
     bbbDescr2 <- scale(bbbDescr[, apply(bbbDescr, 2, function(x) length(unique(x)) > 1)])
 
     rpartFit <- train(bbbDescr, logBBB,
@@ -674,6 +751,7 @@ if(FALSE)
                       .n.trees = 20 * (1:20),
                       .shrinkage = .1),
                     verbose = FALSE,
+                    bag.fraction = 0.9,
                     trControl = trainControl(method = "LGOCV", index = tmp))
 
     svmRFit <- train(bbbDescr2, logBBB,
@@ -710,6 +788,7 @@ if(FALSE)
                               gbm = gbmFit))
     
 
+    save.image("bbb.RData")
     resamps
     bwplot(resamps, metric = "RMSE")
     densityplot(resamps,
